@@ -88,8 +88,9 @@ SUPPORTED_LANGUAGES = [
 
 # Training status colour codes
 C_INITIATED = "⚪"
-C_QUEUED = "🟠"
+C_QUEUED = "🔵"
 C_COMPLETED = "🟢"
+C_TRAINING = "🟠"
 C_FAILED = "🔴"
 C_TIMED_OUT = "🟤"
 C_DEAD = "⚫"
