@@ -214,13 +214,12 @@ def print_ner_response(list_of_entities: List[Dict[Text, Text]], original_text:
             end_index = entities[END_INDEX]
             marked_sentence = ""
             for idx, character in enumerate(original_text):
-                if start_index == 0:
-                    marked_sentence += "[bold green]"
                 if idx == start_index:
                     marked_sentence += "[bold green]"
                 elif idx == end_index:
                     marked_sentence += "[/bold green]"
                 marked_sentence += character
+            console.log(start_index, end_index)
             if entities[TYPE] == TIME and isinstance(entities[VALUE], dict):
                 type_time_format = (
                     f"From: {str(entities[VALUE][FROM])} To: {str(entities[VALUE][TO])}"
